@@ -1,24 +1,62 @@
-#  File ergm/R/ergm.getMCMCsample.R
-#  Part of the statnet package, http://statnet.org
+#  File R/ergm.getMCMCsample.R in package ergm, part of the Statnet suite
+#  of packages for network analysis, http://statnet.org .
 #
 #  This software is distributed under the GPL-3 license.  It is free,
-#  open source, and has the attribution requirements (GPL Section 7) in
-#    http://statnet.org/attribution
+#  open source, and has the attribution requirements (GPL Section 7) at
+#  http://statnet.org/attribution
 #
-#  Copyright 2012 the statnet development team
-######################################################################
+#  Copyright 2003-2013 Statnet Commons
+#######################################################################
+#==============================================================================
+# This file contains the 2 following functions for getting an MCMC sample
+#      <ergm.getMCMCsample>
+#      <ergm.mcmcslave>
+#==============================================================================
+
+
+
+
 #########################################################################################
 # The <ergm.getMCMCsample> function samples networks using an MCMC algorithm via
 # <MCMC_wrapper.C>. Unlike its <ergm.getMCMCsample> counterpart, this function is
 # caple of running in multiple threads.  Note that the returned stats will be relative to
 # the original network, i.e., the calling function must shift the statistics if required. 
 # The calling function must also attach column names to the statistics matrix if required.
+#
+# --PARAMETERS--
+#   nw        :  a network object
+#   model     :  a model for the given 'nw' as returned by <ergm.getmodel>
+#   MHproposal:  a list of the parameters needed for Metropolis-Hastings proposals and
+#                the result of calling <MHproposal>
+#   eta0      :  the initial eta coefficients
+#   verbose   :  whether the C functions should be verbose; default=FALSE
+#   control:  list of MCMC tuning parameters; those recognized include
+#       parallel    : the number of threads in which to run the sampling
+#       packagenames: names of packages; this is only relevant if "ergm" is given
+#       samplesize  : the number of networks to be sampled
+#       interval    : the number of proposals to ignore between sampled networks
+#       burnin      : the number of proposals to initially ignore for the burn-in
+#                     period
+#
+# Note:  In reality, there should be many fewer arguments to this function,
+# since most info should be passed via Clist (this is, after all, what Clist
+# is for:  Holding all arguments required for the .C call).  In particular,
+# the elements of MHproposal, control, verbose should certainly
+# be part of Clist.  But this is a project for another day!
+#
+# --RETURNED--
+#   the sample as a list containing:
+#     statsmatrix:  the stats matrix for the sampled networks, RELATIVE TO THE ORIGINAL
+#                   NETWORK!
+#     newnetwork :  the edgelist of the final sampled network
+#     nedges     :  the number of edges in the 'newnetwork' ??
+#
 #########################################################################################
 
 ergm.getMCMCsample <- function(nw, model, MHproposal, eta0, control, 
-                                        verbose) {
+                                        verbose, response=NULL) {
   
-  Clist <- ergm.Cprepare(nw, model)
+  Clist <- ergm.Cprepare(nw, model, response=response)
 
   z <- NULL
 
@@ -26,7 +64,9 @@ ergm.getMCMCsample <- function(nw, model, MHproposal, eta0, control,
     flush.console()
     z <- ergm.mcmcslave(Clist,MHproposal,eta0,control,verbose)
     
-    # Note that status code 1 (MCMC_TOO_MANY_EDGES) is handled in ergm.mcmcslave.
+    if(z$status == 1){ # MCMC_TOO_MANY_EDGES, exceeding even control$MCMC.max.maxedges
+      return(list(status=z$status))
+    }
     
     if(z$status == 2){ # MCMC_MH_FAILED
       # MH proposal failed somewhere. Throw an error.
@@ -38,15 +78,16 @@ ergm.getMCMCsample <- function(nw, model, MHproposal, eta0, control,
     statsmatrix <- matrix(z$s, nrow=control$MCMC.samplesize,
                           ncol=Clist$nstats,
                           byrow = TRUE)
-    newnetwork <- newnw.extract(nw,z,output=control$network.output)
+    newnetwork <- newnw.extract(nw,z,response=response,
+                                output=control$network.output)
     newnetworks <- list(newnetwork)
   }else{
     control.parallel <- control
-    control.parallel$samplesize <- round(control$MCMC.samplesize / control$parallel)
+    control.parallel$MCMC.samplesize <- round(control$MCMC.samplesize / control$parallel)
     
     cl <- ergm.getCluster(control, verbose)
     #
-    #   Run the jobs on a cluster
+    #   Run the jobs with rpvm or Rmpi
     #
     flush.console()
     outlist <- clusterCall(cl,ergm.mcmcslave,
@@ -58,8 +99,11 @@ ergm.getMCMCsample <- function(nw, model, MHproposal, eta0, control,
     newnetworks <- list()
     for(i in (1:control$parallel)){
       z <- outlist[[i]]
-      # Note that status code 1 (MCMC_TOO_MANY_EDGES) is handled in ergm.mcmcslave.
 
+      if(z$status == 1){ # MCMC_TOO_MANY_EDGES, exceeding even control$MCMC.max.maxedges
+        return(list(status=z$status))
+      }
+      
       if(z$status == 2){ # MCMC_MH_FAILED
         # MH proposal failed somewhere. Throw an error.
         stop("Sampling failed due to a Metropolis-Hastings proposal failing.")
@@ -68,14 +112,14 @@ ergm.getMCMCsample <- function(nw, model, MHproposal, eta0, control,
       if(!is.null(z$burnin.failed) && z$burnin.failed) warning("Burn-in failed to converge after retries.")
       
       statsmatrix <- rbind(statsmatrix,
-                           matrix(z$s, nrow=control.parallel$samplesize,
+                           matrix(z$s, nrow=control.parallel$MCMC.samplesize,
                                   ncol=Clist$nstats,
                                   byrow = TRUE))
     }
 
-    newnetworks[[i]]<-newnetwork<-newnw.extract(nw,z,output=control$network.output)
+    newnetworks[[i]]<-newnetwork<-newnw.extract(nw,z,response=response)
     if(verbose){cat("parallel samplesize=",nrow(statsmatrix),"by",
-                    control.parallel$samplesize,"\n")}
+                    control.parallel$MCMC.samplesize,"\n")}
     
     ergm.stopCluster(cl)
   }
@@ -83,7 +127,7 @@ ergm.getMCMCsample <- function(nw, model, MHproposal, eta0, control,
   colnames(statsmatrix) <- model$coef.names
 
   statsmatrix[is.na(statsmatrix)] <- 0
-  list(statsmatrix=statsmatrix, newnetwork=newnetwork, newnetworks=newnetworks)
+  list(statsmatrix=statsmatrix, newnetwork=newnetwork, newnetworks=newnetworks, status=0)
 }
 
 
@@ -94,6 +138,26 @@ ergm.getMCMCsample <- function(nw, model, MHproposal, eta0, control,
 # The <ergm.mcmcslave> function is that which the slaves will call to perform
 # a validation on the mcmc equal to their slave number. It also returns an
 # MCMC sample.
+#
+# --PARAMETERS--
+#   Clist     : the list of parameters returned by <ergm.Cprepare>
+#   MHproposal: the MHproposal list as returned by <getMHproposal>
+#   eta0      : the canonical eta parameters
+#   control: a list of parameters for controlling the MCMC algorithm;
+#               recognized components include:
+#       samplesize  : the number of networks to be sampled
+#       interval    : the number of proposals to ignore between sampled networks
+#       burnin      : the number of proposals to initially ignore for the burn-in
+#                     period
+#   verbose   : whether the C code should be verbose (T or F) 
+#
+# --RETURNED--
+#   the MCMC sample as a list of the following:
+#     s         : the statsmatrix
+#     newnwtails: the vector of tails for the new network- is this the final
+#                 network sampled? - is this the original nw if 'maxedges' is 0
+#     newnwheads: the vector of heads for the new network - same q's
+#
 ###############################################################################
 
 ergm.mcmcslave <- function(Clist,MHproposal,eta0,control,verbose) {
@@ -107,11 +171,13 @@ ergm.mcmcslave <- function(Clist,MHproposal,eta0,control,verbose) {
       nedges <- c(Clist$nedges,0,0)
       tails <- Clist$tails
       heads <- Clist$heads
+      weights <- Clist$weights
       stats <- rep(0, Clist$nstats)
     }else{ # Pick up where we left off
       nedges <- prev.run$newnwtails[1]
       tails <- prev.run$newnwtails[2:(nedges+1)]
       heads <- prev.run$newnwheads[2:(nedges+1)]
+      weights <- prev.run$newnwweights[2:(nedges+1)]
       nedges <- c(nedges,0,0)
       stats <- matrix(prev.run$s,
                       ncol=Clist$nstats,
@@ -125,6 +191,7 @@ ergm.mcmcslave <- function(Clist,MHproposal,eta0,control,verbose) {
     if(is.null(maxedges)) maxedges <- control$MCMC.init.maxedges
 
     repeat{
+      if(is.null(Clist$weights)){
         z <- .C("MCMC_wrapper",
                 as.integer(numnetworks), as.integer(nedges),
                 as.integer(tails), as.integer(heads),
@@ -133,7 +200,7 @@ ergm.mcmcslave <- function(Clist,MHproposal,eta0,control,verbose) {
                 as.integer(Clist$nterms),
                 as.character(Clist$fnamestring),
                 as.character(Clist$snamestring),
-                as.character(MHproposal$name), as.character(MHproposal$package),
+                as.character(MHproposal$name), as.character(MHproposal$pkgname),
                 as.double(c(Clist$inputs,MHproposal$inputs)), as.double(eta0),
                 as.integer(samplesize),
                 s = as.double(rep(stats, samplesize)),
@@ -151,11 +218,40 @@ ergm.mcmcslave <- function(Clist,MHproposal,eta0,control,verbose) {
         
         # save the results
         z<-list(s=z$s, newnwtails=z$newnwtails, newnwheads=z$newnwheads, status=z$status, maxedges=maxedges)
-
+      }else{
+        z <- .C("WtMCMC_wrapper",
+                as.integer(length(nedges)), as.integer(nedges),
+                as.integer(tails), as.integer(heads), as.double(weights),
+                as.integer(Clist$n),
+                as.integer(Clist$dir), as.integer(Clist$bipartite),
+                as.integer(Clist$nterms),
+                as.character(Clist$fnamestring),
+                as.character(Clist$snamestring),
+                as.character(MHproposal$name), as.character(MHproposal$pkgname),
+                as.double(c(Clist$inputs,MHproposal$inputs)), as.double(eta0),
+                as.integer(samplesize),
+                s = as.double(rep(stats, samplesize)),
+                as.integer(burnin), 
+                as.integer(interval),
+                newnwtails = integer(maxedges),
+                newnwheads = integer(maxedges),
+                newnwweights = double(maxedges),
+                as.integer(verbose), 
+                as.integer(maxedges),
+                status = integer(1),
+                PACKAGE="ergm")
+        # save the results
+        z<-list(s=z$s, newnwtails=z$newnwtails, newnwheads=z$newnwheads, newnwweights=z$newnwweights, status=z$status, maxedges=maxedges)
+      }
       if(z$status!=1) return(z) # Handle everything except for MCMC_TOO_MANY_EDGES elsewhere.
 
       # The following is only executed (and the loop continued) if too many edges.
       maxedges <- maxedges * 10
+      if(!is.null(control$MCMC.max.maxedges)){
+        if(maxedges == control$MCMC.max.maxedges*10) # True iff the previous maxedges exactly equaled control$MCMC.max.maxedges and that was too small.
+          return(z) # This will kick the too many edges problem upstairs, so to speak.
+        maxedges <- min(maxedges, control$MCMC.max.maxedges)
+      }
 
     }
   }
@@ -186,35 +282,8 @@ ergm.mcmcslave <- function(Clist,MHproposal,eta0,control,verbose) {
 
       if(control$MCMC.runtime.traceplot) plot(mcmc(burnin.stats,start=burnin+1,burnin+samplesize*interval,thin=interval),ask=FALSE,smooth=TRUE,density=FALSE)
       
-      ## The following function is a modified version of geweke.diag
-      ## from the coda R package. The original code is Copyright (C)
-      ## 2005-2011 Martyn Plummer, Nicky Best, Kate Cowles, Karen
-      ## Vines
-      ##
-      ## It is incorporated into the ergm package under the terms of
-      ## the GPL v3 license.
-      ##
-      ## coda's implementation uses spectrum0, which is not robust
-      ## enough.
-      my.geweke.diag<-function (x, frac1 = 0.1, frac2 = 0.5){
-        x <- as.mcmc(x)
-        xstart <- c(start(x), end(x) - frac2 * (end(x) - start(x)))
-        xend <- c(start(x) + frac1 * (end(x) - start(x)), end(x))
-        y.variance <- y.mean <- vector("list", 2)
-        for (i in 1:2) {
-          y <- window(x, start = xstart[i], end = xend[i])
-          y.mean[[i]] <- apply(as.matrix(y), 2, mean)
-          y.variance[[i]] <- spectrum0.ar(y)$spec/niter(y)
-        }
-        z <- (y.mean[[1]] - y.mean[[2]])/sqrt(y.variance[[1]] + y.variance[[2]])
-
-        # Output 2-sided P-value, rather than Z score.
-        pnorm(abs(z),0,1,lower.tail=FALSE)*2
-               
-      }
-
       # Bonferroni adjustment
-      failed <- my.geweke.diag(burnin.stats) < control$MCMC.burnin.check.alpha/ncol(burnin.stats)
+      failed <- geweke.diag.ar(burnin.stats)$p.val < control$MCMC.burnin.check.alpha/ncol(burnin.stats)
       # If a statistic didn't mix at all, fail it as well.
       failed[is.na(failed)] <- TRUE
       if(any(failed)){
