@@ -1,15 +1,38 @@
-#  File ergm/R/network.update.R
-#  Part of the statnet package, http://statnet.org
+#  File R/network.update.R in package ergm, part of the Statnet suite
+#  of packages for network analysis, http://statnet.org .
 #
 #  This software is distributed under the GPL-3 license.  It is free,
-#  open source, and has the attribution requirements (GPL Section 7) in
-#    http://statnet.org/attribution
+#  open source, and has the attribution requirements (GPL Section 7) at
+#  http://statnet.org/attribution
 #
-#  Copyright 2012 the statnet development team
-######################################################################
+#  Copyright 2003-2013 Statnet Commons
+#######################################################################
+#============================================================================
+# This file contains the following 3 functions used to update networks:
+#          <network.update>
+#          <as.edgelist.compressed>
+#          <as.network.uncompressed>
+#===========================================================================
+
+
+
 ###############################################################################
 # The <network.update> function returns the given network with with only the
 # ties specified by a given matrix
+#
+# --PARAMETERS--
+#   nw         : a network object
+#   newmatrix  : the matrix specifying the new set of ties with which to
+#                update 'nw' 
+#   matrix.type: the type of matrix that 'newmatrix' is, as "adjacency" or
+#                "edgelist"; default=which.matrix.type(newmatrix)
+#   output     : a string indicating whether the output should be an
+#                edgelist (using "edgelist.compressed") or should be a 
+#                network (using any other string); default="network"
+#
+# --RETURNED--
+#   unw:  the updated network, having only those ties specified by 'newmatrix'
+#
 ###############################################################################
 
 network.update<-function(nw, newmatrix, matrix.type=NULL, output="network")
@@ -49,14 +72,31 @@ network.update<-function(nw, newmatrix, matrix.type=NULL, output="network")
 ###############################################################################
 # The <as.edgelist.compressed> function converts a network 'x' into the edgelist
 # 'out' described below; this is a copy of <as.edgelist.san>
+#
+# --PARAMETERS--
+#   x              : a network object, or a list of such
+#   attrname       : optionally, the name of an edge attribute to use for edge
+#                    values; default=NULL
+#   force.bipartite: whether ?? if 'x' is not already bipartite(T or F); default=FALSE; if TRUE,
+#                    this appears to merely create the 'input must be a network'
+#                    warning, before finishing up as if this were FALSE
+#
+# --RETURNED--
+#   out: x, as an edgelist with attributes for
+#       n                : the network size
+#       directed         : whether the network is directed (T or F)
+#       vnames           : the vertex names
+#       vertex.attributes: a list of the vertex attributes
+#       bipartite        : whether the network is bipartite (T or F)
+#
 ###############################################################################
 
-as.edgelist.compressed<-function(x, attrname=NULL, force.bipartite=FALSE){
+as.edgelist.compressed<-function(x, attrname=NULL, force.bipartite=FALSE, ...){
   #In case of lists, process independently
-  if(is.list(x)&&(!(class(x)%in%c("network"))))
+  if(is.list(x) && !inherits(x,"network"))
     return(lapply(x,as.edgelist.compressed, attrname=attrname, force.bipartite=force.bipartite))
   #Begin with network objects
-  if(class(x)=="network"){
+  if(inherits(x,"network")){
     require("network")  #Must have network library to process network objects
     out<-as.matrix.network.edgelist(x,attrname=attrname)
 #   if(!is.directed(x)){
@@ -93,12 +133,27 @@ as.edgelist.compressed<-function(x, attrname=NULL, force.bipartite=FALSE){
 ###############################################################################
 # The <as.network.uncompressed> function is basically the inverse of the above
 # <as.edgelist.compressed> function
+#
+# --PARAMETERS--
+#   x         : a compressed network or a network
+#   edge.check: whether computationally expensive checks of the legality
+#               of submitted edges should be performed (T or F); default=FALSE
+#
+# --IGNORED PARAMTERS--
+#   na.rm:  whether NA valuse should be removed for ??; default=FALSE
+#   ...  :  additional parameters for flexibility
+#
+# --RETURNED--
+#   x: the original network if it is already uncompressed or if 'x' is neither
+#      a compressed or uncompressed network
+#   g: the uncompressed version of x
+#
 ###############################################################################
 
 as.network.uncompressed<-function(x, 
         na.rm=FALSE, edge.check=FALSE, ...){
   #Initialize the network object
-  if(class(x)=="network"){return(x)}
+  if(inherits(x,"network")){return(x)}
   if(is.null(attr(x,"vnames"))){
    warning("as.network.uncompressed input must be a compressed network, or a network.\n Returning the original object.\n")
    return(x)
