@@ -1,16 +1,16 @@
-#  File ergm/R/parallel.utils.R
-#  Part of the statnet package, http://statnet.org
+#  File R/parallel.utils.R in package ergm, part of the Statnet suite
+#  of packages for network analysis, http://statnet.org .
 #
 #  This software is distributed under the GPL-3 license.  It is free,
-#  open source, and has the attribution requirements (GPL Section 7) in
-#    http://statnet.org/attribution
+#  open source, and has the attribution requirements (GPL Section 7) at
+#  http://statnet.org/attribution
 #
-#  Copyright 2012 the statnet development team
-######################################################################
+#  Copyright 2003-2013 Statnet Commons
+#######################################################################
 # Set up a flag for whether we are in charge of MPI cluster.
 ergm.MPIcluster.started <- local({
   started <- FALSE
-  function(new) {
+  function(new){
     if(!missing(new))
       started <<- new
     else
@@ -18,12 +18,24 @@ ergm.MPIcluster.started <- local({
   }
 })
 
+ergm.MCMC.packagenames <- local({
+  packagenames <- c("ergm") # It has to include itself.
+  function(new){
+    if(!missing(new))
+      packagenames <<- unique(c(packagenames,new))
+    else
+      packagenames
+  }
+})
+
 myLibLoc <- function()
   sub('/ergm/Meta/package.rds','',attr(packageDescription("ergm"),"file"))
 
 # Acquires a cluster of specified type.
 ergm.getCluster <- function(control, verbose=FALSE){
-  capture.output(require(snow, quietly=TRUE, warn.conflicts = FALSE))
+  capture.output(library(snow, quietly=TRUE, warn.conflicts = FALSE))
+# The rpvm package is apparently not being maintained.
+#  capture.output(require(rpvm, quietly=TRUE, warn.conflicts = FALSE))
 
   type <- if(is.null(control$parallel.type)) getClusterOption("type") else control$parallel.type
 
@@ -31,6 +43,17 @@ ergm.getCluster <- function(control, verbose=FALSE){
     #   Start Cluster
 
   cl <- switch(type,
+# The rpvm package is apparently not being maintained.
+               PVM={              
+#                capture.output(require(rpvm, quietly=TRUE, warn.conflicts = FALSE))
+#                PVM.running <- try(.PVM.config(), silent=TRUE)
+#                if(inherits(PVM.running,"try-error")){
+#                  hostfile <- paste(Sys.getenv("HOME"),"/.xpvm_hosts",sep="")
+#                  .PVM.start.pvmd(hostfile)
+#                  cat("PVM not running. Attempting to start.\n")
+#                }
+                 makeCluster(control$parallel,type="PVM")
+               },
                MPI={
                  # See if a preexisting cluster exists.
                  if(is.null(getMPIcluster())){
@@ -47,25 +70,26 @@ ergm.getCluster <- function(control, verbose=FALSE){
   
   # Set things up. 
   clusterSetupRNG(cl)
-  if("ergm" %in% control$MCMC.packagenames){
-
+  # On the off chance that user wants to load extra packages which we don't know about already.
+  ergm.MCMC.packagenames(control$MCMC.packagenames)
+  for(pkg in ergm.MCMC.packagenames()){
     # Try loading from the same location as the master.
     attached <- unlist(clusterCall(cl, require,
-                                   package="ergm",
+                                   package=pkg,
                                    character.only=TRUE,
                                    lib.loc=myLibLoc()))
     # If something failed, warn and try loading from anywhere.
     if(!all(attached)){
       if(verbose) cat("Failed to attach ergm on the slave nodes from the same location as the master node. Will try to load from anywhere in the library path.\n")
       attached <- clusterCall(cl, require,
-                            package="ergm",
+                            package=pkg,
                             character.only=TRUE)      
       if(!all(attached)) stop("Failed to attach ergm on one or more slave nodes. Make sure it's installed on or accessible from all of them and is in the library path.")
     }
     
     if(control$parallel.version.check){
-      slave.versions <- clusterCall(cl,packageVersion,"ergm")
-      master.version <- packageVersion("ergm")
+      slave.versions <- clusterCall(cl,packageVersion,pkg)
+      master.version <- packageVersion(pkg)
 
       if(!all(sapply(slave.versions,identical,master.version)))
         stop("The version of ergm attached on one or more slave nodes is different from from that on the master node (this node). Make sure the same version is installed on all nodes. If you are absolutely certain that this message is in error, override with the parallel.version.check=FALSE control parameter.")
