@@ -1,14 +1,15 @@
-#  File ergm/tests/mple_target.stats.R
-#  Part of the statnet package, http://statnet.org
+#  File tests/mple_target.stats.R in package ergm, part of the Statnet suite
+#  of packages for network analysis, http://statnet.org .
 #
 #  This software is distributed under the GPL-3 license.  It is free,
-#  open source, and has the attribution requirements (GPL Section 7) in
-#    http://statnet.org/attribution
+#  open source, and has the attribution requirements (GPL Section 7) at
+#  http://statnet.org/attribution
 #
-#  Copyright 2012 the statnet development team
-######################################################################
+#  Copyright 2003-2013 Statnet Commons
+#######################################################################
+library(statnet.common)
+opttest({
 library(ergm)
-library(coda)
 n<-500
 base.net <- network.initialize(n=n,directed=FALSE)
 norm.stats<-c(.7,.1,.5)
@@ -26,3 +27,4 @@ target.stats.sim<-apply(ergm.sim,2,mean)
 print(target.stats.sim)
 print(effectiveSize(mcmc(ergm.sim)))
 print((target.stats.sim-target.stats)/sqrt(apply(ergm.sim,2,var)/effectiveSize(mcmc(ergm.sim))))
+}, "MPLE + target statistics")
