@@ -1,12 +1,12 @@
-#  File ergm/tests/termTests.bipartite.R
-#  Part of the statnet package, http://statnetproject.org
+#  File tests/termTests.bipartite.R in package ergm, part of the Statnet suite
+#  of packages for network analysis, http://statnet.org .
 #
 #  This software is distributed under the GPL-3 license.  It is free,
-#  open source, and has the attribution requirements (GPL Section 7) in
-#    http://statnetproject.org/attribution
+#  open source, and has the attribution requirements (GPL Section 7) at
+#  http://statnet.org/attribution
 #
-#  Copyright 2011 the statnet development team
-######################################################################
+#  Copyright 2003-2013 Statnet Commons
+#######################################################################
 
 library(ergm)
 #library(network)  This is not necessary; ergm already depends on network
@@ -26,7 +26,7 @@ set.seed(258)
 b1 <- floor(runif(150, 1,200))
 b2 <- floor(runif(150, 201, 400))
 exbip.el <- cbind(b1,b2)
-bipnw2 <- as.network(exbip.el, matrix.type="edgelist", bipartite=100, directed=FALSE)
+bipnw2 <- as.network(exbip.el, matrix.type="edgelist", bipartite=200, directed=FALSE)
 bipnw2 %v% "Letter" <- letters[1:2]
 color <- rbinom(400, 1, .4)
 color[color ==1] <- "Purple"
@@ -41,9 +41,9 @@ num.tests=0
 #b1concurrent, bipartite, undirected
 num.tests=num.tests+1
 s.0 <- summary(bipnw~b1concurrent)
-e.0 <- ergm(bipnw~b1concurrent, MPLEonly=TRUE)
+e.0 <- ergm(bipnw~b1concurrent, estimate="MPLE")
 s.b <- summary(bipnw~b1concurrent("Letter"))
-e.b <- ergm(bipnw~b1concurrent("Letter"), MPLEonly=TRUE)
+e.b <- ergm(bipnw~b1concurrent("Letter"), estimate="MPLE")
 if (s.0 != 12 || round(e.0$coef + 3.961, 3) != 0 ||
     !all(s.b==c(4,5,3)) ||
     !all(round(e.b$coef+c(4.143, 3.62, 4.105),3)==0)) {
@@ -58,9 +58,9 @@ if (s.0 != 12 || round(e.0$coef + 3.961, 3) != 0 ||
 #b1degree, bipartite, undirected
 num.tests=num.tests+1
 s.d <- summary(bipnw~b1degree(1:3))
-e.d <- ergm(bipnw~b1degree(1:3), MPLEonly=TRUE)
+e.d <- ergm(bipnw~b1degree(1:3), estimate="MPLE")
 s.db <- summary(bipnw~b1degree(2:4, by="Letter"))
-e.db <- ergm(bipnw~b1degree(2, by="Letter"), MPLEonly=TRUE)
+e.db <- ergm(bipnw~b1degree(2, by="Letter"), estimate="MPLE")
 if (!all(s.d==c(30,8,2)) ||
     !all(round(e.d$coef+c(2.991, 5.442, 6.484),3)==0) ||
     !all(s.db==c(2,1,1,3,1,1,3,0,0)) ||
@@ -78,9 +78,9 @@ if (!all(s.d==c(30,8,2)) ||
 #b1factor, bipartite, undirected
 num.tests=num.tests+1
 s.a <- summary(bipnw~b1factor("Letter"))
-e.a <- ergm(bipnw~b1factor("Letter"), MPLEonly=TRUE)
+e.a <- ergm(bipnw~b1factor("Letter"), estimate="MPLE")
 s.ab <- summary(bipnw~b1factor("Letter", base=3))
-e.ab <- ergm(bipnw~b1factor("Letter", base=2), MPLEonly=TRUE)
+e.ab <- ergm(bipnw~b1factor("Letter", base=2), estimate="MPLE")
 if (!all(s.a==c(21,19)) ||
     !all(round(e.a$coef+c(3.797, 3.899),3)==0) ||
     !all(s.ab==c(20,21)) ||
@@ -97,9 +97,9 @@ if (!all(s.a==c(21,19)) ||
 #b1star, bipartite, undirected
 num.tests=num.tests+1
 s.k <- summary(bipnw~b1star(1:2))
-e.k <- ergm(bipnw~b1star(1:2), MPLEonly=TRUE)
+e.k <- ergm(bipnw~b1star(1:2), estimate="MPLE")
 s.ka <- summary(bipnw~b1star(2:3, "Letter"))
-e.ka <- ergm(bipnw~b1star(2:2, "Letter"), MPLEonly=TRUE)
+e.ka <- ergm(bipnw~b1star(2:2, "Letter"), estimate="MPLE")
 if (!all(s.k==c(60,26)) ||
     !all(round(e.k$coef+c(4.0823, -.3179),3)==0) ||
     !all(s.ka==c(3,0)) ||
@@ -117,20 +117,20 @@ if (!all(s.k==c(60,26)) ||
 #b1starmix, bipartite, undirected
 num.tests=num.tests+1
 s.ka <- summary(bipnw2~b1starmix(2, "Letter"))
-e.ka <- ergm(bipnw2~b1starmix(2, "Letter"), MPLEonly=TRUE)
+e.ka <- ergm(bipnw2~b1starmix(2, "Letter"), estimate="MPLE")
 s.kab <- summary(bipnw2~b1starmix(1, "Letter", base=2))
-e.kab <- ergm(bipnw2~b1starmix(1, "Letter", base=2:3), MPLEonly=TRUE)
+e.kab <- ergm(bipnw2~b1starmix(1, "Letter", base=2:3), estimate="MPLE")
 s.kad <- summary(bipnw2~b1starmix(1, "Letter", diff=FALSE))
-e.kad <- ergm(bipnw2~b1starmix(1, "Letter", diff=FALSE), MPLEonly=TRUE)
+e.kad <- ergm(bipnw2~b1starmix(1, "Letter", diff=FALSE), estimate="MPLE")
 s.kabd <- summary(bipnw2~b1starmix(1, "Letter", base=2, diff=FALSE))
-e.kabd <- ergm(bipnw2~b1starmix(1, "Letter", base=2:3, diff=FALSE), MPLEonly=TRUE)
-if (!all(s.ka==c(2,2,5,2)) ||
-    !all(round(e.ka$coef+c(5.915, 6.445, 5.084, 6.244),3)==0) ||
-    !all(s.kab==c(14,18,18)) ||
-    !all(round(e.kab$coef+c(6.275, 6.016),3)==0) ||
-    !all(s.kad==c(32,39)) ||
-    !all(round(e.kad$coef+c(6.138, 5.940),3)==0) ||
-    s.kabd != 32 || round(e.kabd$coef+ 6.138,3)!=0)  {
+e.kabd <- ergm(bipnw2~b1starmix(1, "Letter", base=2:3, diff=FALSE), estimate="MPLE")
+if (!all(s.ka==c(9,4,7,4)) ||
+    !all(round(e.ka$coef+c(4.870, 5.802, 5.267, 5.962),3)==0) ||
+    !all(s.kab==c(36, 39, 40)) ||
+    !all(round(e.kab$coef+c(5.613, 5.497),3)==0) ||
+    !all(s.kad==c(75, 75)) ||
+    !all(round(e.kad$coef+c(5.567, 5.567),3)==0) ||
+    s.kabd != 75 || round(e.kabd$coef+ 5.567,3)!=0)  {
  print(list(s.ka=s.ka, e.ka=e.ka, s.kab=s.kab, e.kab=e.kab,
             s.kad=s.kad, e.kad=e.kad, s.kabd=s.kabd, e.kabd=e.kabd))
  stop("Failed b1starmix term test")
@@ -144,21 +144,21 @@ if (!all(s.ka==c(2,2,5,2)) ||
 #b1twostar, bipartite, undirected
 num.tests=num.tests+1
 s.a <- summary(bipnw2~b1twostar("Letter"))
-e.a <- ergm(bipnw2~b1twostar("Letter"), MPLEonly=TRUE)
+e.a <- ergm(bipnw2~b1twostar("Letter"), estimate="MPLE")
 s.aa <- summary(bipnw2~b1twostar("Letter", "Color"))
-e.aa <- ergm(bipnw2~b1twostar("Letter", "Color"), MPLEonly=TRUE)
+e.aa <- ergm(bipnw2~b1twostar("Letter", "Color"), estimate="MPLE")
 s.ab <- summary(bipnw2~b1twostar("Letter", base=2:4))
-e.ab <- ergm(bipnw2~b1twostar("Letter", base=c(1,3,5)), MPLEonly=TRUE)
+e.ab <- ergm(bipnw2~b1twostar("Letter", base=c(1,3,5)), estimate="MPLE")
 s.aab <- summary(bipnw2~b1twostar("Letter", "Color", base=2:4))
-e.aab <- ergm(bipnw2~b1twostar("Letter", "Color", base=c(1,3,5)), MPLEonly=TRUE)
+e.aab <- ergm(bipnw2~b1twostar("Letter", "Color", base=c(1,3,5)), estimate="MPLE")
 if (!all(s.a==c(9,4,15,17,7,4)) ||
-    !all(round(e.a$coef+c(5.688, 6.012, 5.223, 5.463, 4.635, 5.688),3)==0) ||
-    !all(s.aa==c(12,3,18,10,8,5)) ||
-    !all(round(e.aa$coef+c(5.174, 6.789, 5.155, 5.299, 4.996, 5.587),3)==0) ||
+    !all(round(e.a$coef+c(4.523, 5.22, 4.773, 4.593, 4.881, 5.446),3)==0) ||
+    !all(s.aa==c(13,2,13,15,5,8)) ||
+    !all(round(e.aa$coef+c(4.548, 6.281, 4.882, 4.702, 4.758, 4.364),3)==0) ||
     !all(s.ab==c(9,7,4)) ||
-    !all(round(e.ab$coef+c(6.012, 5.463, 5.688),3)==0) ||
-    !all(s.aab==c(12,8,5)) ||
-    !all(round(e.aab$coef+c(6.789, 5.299, 5.587),3)==0)) {
+    !all(round(e.ab$coef+c(5.22, 4.593, 5.446),3)==0) ||
+    !all(s.aab==c(13,5,8)) ||
+    !all(round(e.aab$coef+c(6.281, 4.702, 4.364),3)==0)) {
  print(list(s.a=s.a, e.a=e.a, s.aa=s.aa, e.aa=e.aa, s.ab=s.ab, e.ab=e.ab,
             s.aab=s.aab, e.aab=e.aab))
  stop("Failed b1twostar term test")
@@ -172,9 +172,9 @@ if (!all(s.a==c(9,4,15,17,7,4)) ||
 #b2concurrent, bipartite, undirected
 num.tests=num.tests+1
 s.0 <- summary(bipnw~b2concurrent)
-e.0 <- ergm(bipnw~b2concurrent, MPLEonly=TRUE)
+e.0 <- ergm(bipnw~b2concurrent, estimate="MPLE")
 s.b <- summary(bipnw~b2concurrent("Letter"))
-e.b <- ergm(bipnw~b2concurrent("Letter"), MPLEonly=TRUE)
+e.b <- ergm(bipnw~b2concurrent("Letter"), estimate="MPLE")
 if (s.0 != 20 || round(e.0$coef + 3.497, 3) != 0 ||
     !all(s.b==c(8,6,6)) ||
     !all(round(e.b$coef+c(2.803, 4.190, 2.803),3)==0)) {
@@ -189,9 +189,9 @@ if (s.0 != 20 || round(e.0$coef + 3.497, 3) != 0 ||
 #b2degree, bipartite, undirected
 num.tests=num.tests+1
 s.d <- summary(bipnw~b2degree(1:3))
-e.d <- ergm(bipnw~b2degree(1:3), MPLEonly=TRUE)
+e.d <- ergm(bipnw~b2degree(1:3), estimate="MPLE")
 s.db <- summary(bipnw~b2degree(2:4, by="Letter"))
-e.db <- ergm(bipnw~b2degree(2, by="Letter"), MPLEonly=TRUE)
+e.db <- ergm(bipnw~b2degree(2, by="Letter"), estimate="MPLE")
 if (!all(s.d==c(6,9,8)) ||
     !all(round(e.d$coef-c(1.7203, 1.4941, .6768),3)==0) ||
     !all(s.db==c(3,2,3,3,3,0,3,3,0)) ||
@@ -209,9 +209,9 @@ if (!all(s.d==c(6,9,8)) ||
 #b2factor, bipartite, undirected
 num.tests=num.tests+1
 s.a <- summary(bipnw~b2factor("Letter"))
-e.a <- ergm(bipnw~b2factor("Letter"), MPLEonly=TRUE)
+e.a <- ergm(bipnw~b2factor("Letter"), estimate="MPLE")
 s.ab <- summary(bipnw~b2factor("Letter", base=3))
-e.ab <- ergm(bipnw~b2factor("Letter", base=2), MPLEonly=TRUE)
+e.ab <- ergm(bipnw~b2factor("Letter", base=2), estimate="MPLE")
 if (!all(s.a==c(19,16)) ||
     !all(round(e.a$coef+c(3.944, 4.119),3)==0) ||
     !all(s.ab==c(25,19)) ||
@@ -228,9 +228,9 @@ if (!all(s.a==c(19,16)) ||
 #b2star, bipartite, undirected
 num.tests=num.tests+1
 s.k <- summary(bipnw~b2star(1:2))
-e.k <- ergm(bipnw~b2star(1:2), MPLEonly=TRUE)
+e.k <- ergm(bipnw~b2star(1:2), estimate="MPLE")
 s.ka <- summary(bipnw~b2star(2:3, "Letter"))
-e.ka <- ergm(bipnw~b2star(2:2, "Letter"), MPLEonly=TRUE)
+e.ka <- ergm(bipnw~b2star(2:2, "Letter"), estimate="MPLE")
 if (!all(s.k==c(60,51)) ||
     !all(round(e.k$coef+c(3.3457, .2724),3)==0) ||
     !all(s.ka==c(3,0)) ||
@@ -248,20 +248,20 @@ if (!all(s.k==c(60,51)) ||
 #b2starmix, bipartite, undirected
 num.tests=num.tests+1
 s.ka <- summary(bipnw2~b2starmix(2, "Letter"))
-e.ka <- ergm(bipnw2~b2starmix(1, "Letter"), MPLEonly=TRUE)
+e.ka <- ergm(bipnw2~b2starmix(1, "Letter"), estimate="MPLE")
 s.kab <- summary(bipnw2~b2starmix(1, "Letter", base=2))
-e.kab <- ergm(bipnw2~b2starmix(1, "Letter", base=2:3), MPLEonly=TRUE)
+e.kab <- ergm(bipnw2~b2starmix(1, "Letter", base=2:3), estimate="MPLE")
 s.kad <- summary(bipnw2~b2starmix(1, "Letter", diff=FALSE))
-e.kad <- ergm(bipnw2~b2starmix(1, "Letter", diff=FALSE), MPLEonly=TRUE)
+e.kad <- ergm(bipnw2~b2starmix(1, "Letter", diff=FALSE), estimate="MPLE")
 s.kabd <- summary(bipnw2~b2starmix(1, "Letter", base=2, diff=FALSE))
-e.kabd <- ergm(bipnw2~b2starmix(1, "Letter", base=2:3, diff=FALSE), MPLEonly=TRUE)
-if (!all(s.ka==c(1,4,0,2)) ||
-    !all(round(e.ka$coef+c(6.275, 5.869, 6.016, 6.016),3)==0) ||
-    !all(s.kab==c(14,18,18)) ||
-    !all(round(e.kab$coef+c(6.275, 6.016),3)==0) ||
+e.kabd <- ergm(bipnw2~b2starmix(1, "Letter", base=2:3, diff=FALSE), estimate="MPLE")
+if (!all(s.ka==c(6, 8, 3, 6)) ||
+    !all(round(e.ka$coef+c(5.613, 5.641, 5.523, 5.497),3)==0) ||
+    !all(s.kab==c(36, 39, 40)) ||
+    !all(round(e.kab$coef+c(5.613, 5.497),3)==0) ||
     !all(s.kad==c(71,79)) ||
-    !all(round(e.kad$coef+c(6.051, 6.016),3)==0) ||
-    s.kabd != 71 || round(e.kabd$coef+ 6.051,3)!=0)  {
+    !all(round(e.kad$coef+c(5.627, 5.510),3)==0) ||
+    s.kabd != 71 || round(e.kabd$coef+ 5.627,3)!=0)  {
  print(list(s.ka=s.ka, e.ka=e.ka, s.kab=s.kab, e.kab=e.kab,
             s.kad=s.kad, e.kad=e.kad, s.kabd=s.kabd, e.kabd=e.kabd))
  stop("Failed b2starmix term test")
@@ -275,21 +275,21 @@ if (!all(s.ka==c(1,4,0,2)) ||
 #b2twostar, bipartite, undirected
 num.tests=num.tests+1
 s.a <- summary(bipnw2~b2twostar("Letter"))
-e.a <- ergm(bipnw2~b2twostar("Letter"), MPLEonly=TRUE)
+e.a <- ergm(bipnw2~b2twostar("Letter"), estimate="MPLE")
 s.aa <- summary(bipnw2~b2twostar("Letter", "Color"))
-e.aa <- ergm(bipnw2~b2twostar("Letter", "Color"), MPLEonly=TRUE)
+e.aa <- ergm(bipnw2~b2twostar("Letter", "Color"), estimate="MPLE")
 s.ab <- summary(bipnw2~b2twostar("Letter", base=2:4))
-e.ab <- ergm(bipnw2~b2twostar("Letter", base=c(1,3,5)), MPLEonly=TRUE)
+e.ab <- ergm(bipnw2~b2twostar("Letter", base=c(1,3,5)), estimate="MPLE")
 s.aab <- summary(bipnw2~b2twostar("Letter", "Color", base=2:4))
-e.aab <- ergm(bipnw2~b2twostar("Letter", "Color", base=c(1,3,5)), MPLEonly=TRUE)
+e.aab <- ergm(bipnw2~b2twostar("Letter", "Color", base=c(1,3,5)), estimate="MPLE")
 if (!all(s.a==c(6,3,16,16,8,6)) ||
-    !all(round(e.a$coef+c(5.185, 6.158, 4.892, 4.844, 4.142, 4.901),3)==0) ||
-    !all(s.aa==c(10,6,16,11,3,9)) ||
-    !all(round(e.aa$coef+c(5.25, 5.698, 4.632, 5.331, 4.931, 4.123),3)==0) ||
+    !all(round(e.a$coef+c(5, 5.754, 4.603, 4.780, 4.462, 5.055),3)==0) ||
+    !all(s.aa==c(8, 1, 17, 15, 4, 10)) ||
+    !all(round(e.aa$coef+c(4.823, 6.739, 4.690, 4.702, 5.351, 4.37),3)==0) ||
     !all(s.ab==c(6,8,6)) ||
-    !all(round(e.ab$coef+c(6.158, 4.844, 4.901),3)==0) ||
-    !all(s.aab==c(10,3,9)) ||
-    !all(round(e.aab$coef+c(5.698, 5.331, 4.123),3)==0)) {
+    !all(round(e.ab$coef+c(5.754, 4.78, 5.055),3)==0) ||
+    !all(s.aab==c(8,4,10)) ||
+    !all(round(e.aab$coef+c(6.739, 4.702, 4.370),3)==0)) {
  print(list(s.a=s.a, e.a=e.a, s.aa=s.aa, e.aa=e.aa, s.ab=s.ab, e.ab=e.ab,
             s.aab=s.aab, e.aab=e.aab))
  stop("Failed b2twostar term test")
@@ -302,13 +302,13 @@ if (!all(s.a==c(6,3,16,16,8,6)) ||
 # gwb1degree, bipartite
 num.tests=num.tests+1
 s.d <- summary(bipnw~gwb1degree(.3))
-e.d <- ergm(bipnw~gwb1degree(.4), MPLEonly=TRUE)
+e.d <- ergm(bipnw~gwb1degree(.4), estimate="MPLE")
 s.df <- summary(bipnw~gwb1degree(.3, fixed=TRUE))
-e.df <- ergm(bipnw~gwb1degree(.2, fixed=TRUE), MPLEonly=TRUE)
+e.df <- ergm(bipnw~gwb1degree(.2, fixed=TRUE), estimate="MPLE")
 s.da <- summary(bipnw~gwb1degree(.1, attrname="Letter"))
-e.da <- ergm(bipnw~gwb1degree(.1, attrname="Letter"), MPLEonly=TRUE)
+e.da <- ergm(bipnw~gwb1degree(.1, attrname="Letter"), estimate="MPLE")
 s.dfa <- summary(bipnw~gwb1degree(.1, TRUE, "Letter"))
-e.dfa <- ergm(bipnw~gwb1degree(.1, TRUE, "Letter"), MPLEonly=TRUE)
+e.dfa <- ergm(bipnw~gwb1degree(.1, TRUE, "Letter"), estimate="MPLE")
 if (round(e.d$coef + 6.979, 3) != 0 ||
     round(s.df -45.4137, 3) != 0 ||
     round(e.df$coef + 8.057, 3) != 0 ||
@@ -326,13 +326,13 @@ if (round(e.d$coef + 6.979, 3) != 0 ||
 # gwb2degree, bipartite
 num.tests=num.tests+1
 s.d <- summary(bipnw~gwb2degree(.3))
-e.d <- ergm(bipnw~gwb2degree(.4), MPLEonly=TRUE)
+e.d <- ergm(bipnw~gwb2degree(.4), estimate="MPLE")
 s.df <- summary(bipnw~gwb2degree(.3, fixed=TRUE))
-e.df <- ergm(bipnw~gwb2degree(.2, fixed=TRUE), MPLEonly=TRUE)
+e.df <- ergm(bipnw~gwb2degree(.2, fixed=TRUE), estimate="MPLE")
 s.da <- summary(bipnw~gwb2degree(.1, attrname="Letter"))
-e.da <- ergm(bipnw~gwb2degree(.1, attrname="Letter"), MPLEonly=TRUE)
+e.da <- ergm(bipnw~gwb2degree(.1, attrname="Letter"), estimate="MPLE")
 s.dfa <- summary(bipnw~gwb2degree(.1, TRUE, "Letter"))
-e.dfa <- ergm(bipnw~gwb2degree(.1, TRUE, "Letter"), MPLEonly=TRUE)
+e.dfa <- ergm(bipnw~gwb2degree(.1, TRUE, "Letter"), estimate="MPLE")
 if (round(e.d$coef + 25.99385, 3) != 0 ||
     round(s.df -31.97479, 3) != 0 ||
     round(e.df$coef + 32.78813, 3) != 0 ||
