@@ -1,12 +1,12 @@
-#  File ergm/tests/termTests.undirected.R
-#  Part of the statnet package, http://statnetproject.org
+#  File tests/termTests.undirected.R in package ergm, part of the Statnet suite
+#  of packages for network analysis, http://statnet.org .
 #
 #  This software is distributed under the GPL-3 license.  It is free,
-#  open source, and has the attribution requirements (GPL Section 7) in
-#    http://statnetproject.org/attribution
+#  open source, and has the attribution requirements (GPL Section 7) at
+#  http://statnet.org/attribution
 #
-#  Copyright 2011 the statnet development team
-######################################################################
+#  Copyright 2003-2013 Statnet Commons
+#######################################################################
 
 library(ergm)
 #library(network)  This is not necessary; ergm already depends on network
@@ -36,10 +36,10 @@ num.tests=0
 #altkstar, undirected, 
 num.tests=num.tests+1
 s.0 <- summary(fmh~altkstar)
-e.0 <- ergm(fmh~altkstar, MPLEonly=TRUE)
-e.l <- ergm(fmh~altkstar(.5), MPLEonly=TRUE)
+e.0 <- ergm(fmh~altkstar, estimate="MPLE")
+e.l <- ergm(fmh~altkstar(.5), estimate="MPLE")
 s.f <- summary(fmh~altkstar(fixed=TRUE))
-e.lf <- ergm(fmh~altkstar(.9, fixed=TRUE), MPLEonly=TRUE)
+e.lf <- ergm(fmh~altkstar(.9, fixed=TRUE), estimate="MPLE")
 if (!all(s.0[1:10]==c(51,30,28,18,10,2,4,1,2,1)) ||
     round(e.0$coef+ 3.234, 3) !=0 ||
     round(e.l$coef+ 4.166, 3) !=0 ||
@@ -56,9 +56,9 @@ if (!all(s.0[1:10]==c(51,30,28,18,10,2,4,1,2,1)) ||
 # concurrent, undirected
 num.tests=num.tests+1
 s.0 <- summary(fmh~concurrent)
-e.0 <- ergm(fmh~concurrent, MPLEonly=TRUE)
+e.0 <- ergm(fmh~concurrent, estimate="MPLE")
 s.b <- summary(fmh~concurrent(by="Grade"))
-e.b <- ergm(fmh~concurrent(by="Sex"), MPLEonly=TRUE)
+e.b <- ergm(fmh~concurrent(by="Sex"), estimate="MPLE")
 if (s.0 != 97 || round(e.0$coef + 4.871, 3) != 0 ||
     !all(s.b==c(35,15,18,8,13,8)) ||
     !all(round(e.b$coef + c(5.17301, 4.67697), 3) == 0)) {
@@ -73,11 +73,11 @@ if (s.0 != 97 || round(e.0$coef + 4.871, 3) != 0 ||
 # degree, undirected
 num.tests=num.tests+1
 s.d <- summary(fmh~degree(2:3))
-e.d <- ergm(fmh~degree(0), MPLEonly=TRUE)
+e.d <- ergm(fmh~degree(0), estimate="MPLE")
 s.db <- summary(fmh~degree(1:3, "Grade"))
-e.db <- ergm(fmh~degree(4, "Sex"), MPLEonly=TRUE)
+e.db <- ergm(fmh~degree(4, "Sex"), estimate="MPLE")
 s.dbh <- summary(fmh~degree(4:5, by="Sex", homophily=TRUE))
-e.dbh <- ergm(fmh~degree(2, by="Grade", homophily=TRUE), MPLEonly=TRUE)
+e.dbh <- ergm(fmh~degree(2, by="Grade", homophily=TRUE), estimate="MPLE")
 if (!all(s.d==c(30,28)) || round(e.d$coef - 5.11, 3) != 0 ||
     !all(s.db==c(15,9,9,9,4,2,11,5,9,9,4,2,5,5,4,2,3,2)) ||
     !all(round(e.db$coef+c(.345, .6005),3)==0) ||
@@ -89,15 +89,26 @@ if (!all(s.d==c(30,28)) || round(e.d$coef - 5.11, 3) != 0 ||
   num.passed.tests = num.passed.tests+1
 }
 
+# degreepopularity, undirected
+num.tests=num.tests + 1
+s.0 <- summary(fmh~degreepopularity)
+e.0 <- ergm(fmh~degreepopularity, estimate="MPLE")
+if (round(s.0-795.7458,3) != 0 || round(e.0$coef + 1.1398, 3) != 0) {
+ print(list(s.0=s.0, e.0=e.0))
+ stop("Failed degreepopularity term test")
+} else {
+  num.passed.tests=num.passed.tests+1
+  print("Passed degreepopularity term test")
+}
 
 # gwdegree, undirected
 num.tests=num.tests+1
 s.d <- summary(fmh~gwdegree(.3))
-e.d <- ergm(fmh~gwdegree(.4), MPLEonly=TRUE)
+e.d <- ergm(fmh~gwdegree(.4), estimate="MPLE")
 s.df <- summary(fmh~gwdegree(.3, fixed=TRUE))
-e.df <- ergm(fmh~gwdegree(.2, fixed=TRUE), MPLEonly=TRUE)
+e.df <- ergm(fmh~gwdegree(.2, fixed=TRUE), estimate="MPLE")
 s.dfa <- summary(fmh~gwdegree(.1, fixed=TRUE, attrname="Grade"))
-e.dfa <- ergm(fmh~gwdegree(.1, fixed=TRUE, attrname="Grade"), MPLEonly=TRUE)
+e.dfa <- ergm(fmh~gwdegree(.1, fixed=TRUE, attrname="Grade"), estimate="MPLE")
 if (!all(head(s.d)==c(51,30,28,18,10,2)) ||
     round(e.d$coef + 13.59067, 3) != 0 ||
     round(s.df - 178.4312, 3) != 0 ||
@@ -116,9 +127,9 @@ if (!all(head(s.d)==c(51,30,28,18,10,2)) ||
 # kstar, undirected
 num.tests=num.tests+1
 s.k <- summary(fmh~kstar(1:3))
-e.k <- ergm(fmh~kstar(c(2,4)), MPLEonly=TRUE)
+e.k <- ergm(fmh~kstar(c(2,4)), estimate="MPLE")
 s.ka <- summary(fmh~kstar(2, "Grade"))
-e.ka <- ergm(fmh~kstar(2, "Sex"), MPLEonly=TRUE)
+e.ka <- ergm(fmh~kstar(2, "Sex"), estimate="MPLE")
 if (!all(s.k == c(406, 659, 1010)) ||
     round(e.k$coef - c(-1.45086, .06255), 3) != 0 ||
     s.ka != 466 || round(e.ka$coef + 1.535175, 3) != 0) {
@@ -135,7 +146,7 @@ s.0 <- summary(fmh~sociality)
 s.a <- summary(fmh~sociality("Race"))
 s.b <- summary(fmh~sociality(base=2:203))
 s.ab <- summary(fmh~sociality("Race", base=3:200))
-e.ab <- ergm(fmh~sociality("Race", base=3:205), MPLEonly=TRUE)
+e.ab <- ergm(fmh~sociality("Race", base=3:205), estimate="MPLE")
 if (!all(head(s.0)==c(4,0,0,1,0,0)) ||
     !all(s.a[45:50]==c(0,8,0,0,0,3)) ||
     !all(s.b==c(13,3,1)) ||
@@ -153,11 +164,11 @@ if (!all(head(s.0)==c(4,0,0,1,0,0)) ||
 # num.tests=num.tests+1
 # all of these are turning out 0 or NA                
 #s.0 <- summary(unnw~tripercent)
-#e.0 <- ergm(unnw~tripercent, MPLEonly=TRUE)
+#e.0 <- ergm(unnw~tripercent, estimate="MPLE")
 #s.a <- summary(unnw~tripercent("Pet"))
-#e.a <- ergm(unnw~tripercent("Pet"), MPLEonly=TRUE)                
+#e.a <- ergm(unnw~tripercent("Pet"), estimate="MPLE")                
 #s.ad <- summary(unnw~tripercent("Race", diff=TRUE))
-#e.ad <- ergm(unnw~tripercent("Race", diff=TRUE), MPLEonly=TRUE)   
+#e.ad <- ergm(unnw~tripercent("Race", diff=TRUE), estimate="MPLE")   
 #if (s.0 != 62 || round(e.0$coef + .06997, 3) != 0 ||
 #    s.a != 18 || round(e.a$coef - .06354, 3) != 0 ||
 #    !all(s.ad==c(2,0,0)) ||
